@@ -311,13 +311,8 @@ bool ProtocolDB::loadDB(const QString &filename,const QStringList &languages) {
     
     // Copy the list of permitted languages one by one. Convert things
     // like 'en_GB' to just 'en'.
-    int i;
-    for(i=0; i<languages.count(); i++) {
-        if(languages[i].length()>2) {
-            languagelist.append(languages[i].left(2));
-        } else {
-            languagelist.append(languages[i]);
-        }
+    for(QStringList::ConstIterator lang = languages.begin(); lang != languages.end(); ++lang) {
+        languagelist.append((*lang).left(2));
     }
         
     xmlfile = new QFile(filename);
@@ -359,8 +354,8 @@ cleanup:
 }
 
 ///////////////////////////////////////////////////////////////////////////
-bool ProtocolDB::startElement(const QString &namespaceURI, const QString &localName,
-        const QString &qName, const QXmlAttributes &atts) {
+bool ProtocolDB::startElement(const QString &/*namespaceURI*/, const QString &localName,
+        const QString &/*qName*/, const QXmlAttributes &atts) {
     int i,j;
     QString protocolname;
     QString tmp;
@@ -567,8 +562,6 @@ bool ProtocolDB::startElement(const QString &namespaceURI, const QString &localN
 							currentnetuse->source = ENTITY_CLIENT;
 						} else if(tmp=="server") {
 							currentnetuse->source = ENTITY_SERVER;
-						} else if(tmp=="host") {
-							currentnetuse->source = ENTITY_HOST;
 						} else {
 							errorstate = PROTOCOL_ERROR_TCP_SOURCE_UNKNOWN;
                             return false;
@@ -582,8 +575,6 @@ bool ProtocolDB::startElement(const QString &namespaceURI, const QString &localN
 							currentnetuse->dest = ENTITY_CLIENT;
 						} else if(tmp=="server") {
 							currentnetuse->dest = ENTITY_SERVER;
-						} else if(tmp=="host") {
-							currentnetuse->dest = ENTITY_HOST;
 						} else {
 							errorstate = PROTOCOL_ERROR_TCP_DEST_UNKNOWN;
                             return false;
@@ -603,8 +594,6 @@ bool ProtocolDB::startElement(const QString &namespaceURI, const QString &localN
 							currentnetuse->source = ENTITY_CLIENT;
 						} else if(tmp=="server") {
 							currentnetuse->source = ENTITY_SERVER;
-						} else if(tmp=="host") {
-							currentnetuse->source = ENTITY_HOST;
 						} else {
 							errorstate = PROTOCOL_ERROR_UDP_SOURCE_UNKNOWN;
                             return false;
@@ -618,8 +607,6 @@ bool ProtocolDB::startElement(const QString &namespaceURI, const QString &localN
 							currentnetuse->dest = ENTITY_CLIENT;
 						} else if(tmp=="server") {
 							currentnetuse->dest = ENTITY_SERVER;
-						} else if(tmp=="host") {
-							currentnetuse->dest = ENTITY_HOST;
 						} else {
 							errorstate = PROTOCOL_ERROR_UDP_DEST_UNKNOWN;
                             return false;
@@ -645,8 +632,6 @@ bool ProtocolDB::startElement(const QString &namespaceURI, const QString &localN
 							currentnetuse->source = ENTITY_CLIENT;
 						} else if(tmp=="server") {
 							currentnetuse->source = ENTITY_SERVER;
-						} else if(tmp=="host") {
-							currentnetuse->source = ENTITY_HOST;
 						} else {
 							errorstate = PROTOCOL_ERROR_ICMP_SOURCE_UNKNOWN;
                             return false;
@@ -660,8 +645,6 @@ bool ProtocolDB::startElement(const QString &namespaceURI, const QString &localN
 							currentnetuse->dest = ENTITY_CLIENT;
 						} else if(tmp=="server") {
 							currentnetuse->dest = ENTITY_SERVER;
-						} else if(tmp=="host") {
-							currentnetuse->dest = ENTITY_HOST;
 						} else {
 							errorstate = PROTOCOL_ERROR_ICMP_DEST_UNKNOWN;
                             return false;
@@ -676,7 +659,7 @@ bool ProtocolDB::startElement(const QString &namespaceURI, const QString &localN
 						
 						// Handle the Protocol attribute.
 				    i = atts.index(protocolnamespace,protocolattr);
-				    if(i!=1) {
+				    if(i!=-1) {
 						tmp = atts.value(i);
                         x = tmp.toUInt(&ok);
                         if(ok==false) {
@@ -700,8 +683,6 @@ bool ProtocolDB::startElement(const QString &namespaceURI, const QString &localN
 							currentnetuse->source = ENTITY_CLIENT;
 						} else if(tmp=="server") {
 							currentnetuse->source = ENTITY_SERVER;
-						} else if(tmp=="host") {
-							currentnetuse->source = ENTITY_HOST;
 						} else {
 							errorstate = PROTOCOL_ERROR_IP_SOURCE_UNKNOWN;
                             return false;
@@ -715,8 +696,6 @@ bool ProtocolDB::startElement(const QString &namespaceURI, const QString &localN
 							currentnetuse->dest = ENTITY_CLIENT;
 						} else if(tmp=="server") {
 							currentnetuse->dest = ENTITY_SERVER;
-						} else if(tmp=="host") {
-							currentnetuse->dest = ENTITY_HOST;
 						} else {
 							errorstate = PROTOCOL_ERROR_IP_DEST_UNKNOWN;
                             return false;
@@ -1020,8 +999,8 @@ void ProtocolDB::doNetuseLanguage(const QXmlAttributes &atts) {
 }
 
 ///////////////////////////////////////////////////////////////////////////
-bool ProtocolDB::endElement(const QString &namespaceURI, const QString &localName,
-        const QString &qName) {
+bool ProtocolDB::endElement(const QString &/*namespaceURI*/, const QString &/*localName*/,
+        const QString &/*qName*/) {
 
     if(unknowndepth==0) {
         switch(parsestate) {
